Index: net/url_request/url_request_file_dir_job.cc |
diff --git a/net/url_request/url_request_file_dir_job.cc b/net/url_request/url_request_file_dir_job.cc |
index 23ff6ff9e86fd97d134e712705309ff2e2c3ce1b..968b404573fa1ca53ceb2f55c636df4cfa8027af 100644 |
--- a/net/url_request/url_request_file_dir_job.cc |
+++ b/net/url_request/url_request_file_dir_job.cc |
@@ -20,7 +20,7 @@ |
using std::string; |
-URLRequestFileDirJob::URLRequestFileDirJob(URLRequest* request, |
+URLRequestFileDirJob::URLRequestFileDirJob(net::URLRequest* request, |
const FilePath& dir_path) |
: URLRequestJob(request), |
dir_path_(dir_path), |
@@ -62,9 +62,9 @@ void URLRequestFileDirJob::Kill() { |
canceled_ = true; |
// Don't call CloseLister or dispatch an error to the URLRequest because we |
// want OnListDone to be called to also write the error to the output stream. |
// OnListDone will notify the URLRequest at this time. |
if (lister_) |
lister_->Cancel(); |
@@ -62,9 +62,9 @@ void URLRequestFileDirJob::Kill() { |
canceled_ = true; |
- // Don't call CloseLister or dispatch an error to the URLRequest because we |
- // want OnListDone to be called to also write the error to the output stream. |
- // OnListDone will notify the URLRequest at this time. |
+ // Don't call CloseLister or dispatch an error to the net::URLRequest because |
+ // we want OnListDone to be called to also write the error to the output |
+ // stream. OnListDone will notify the net::URLRequest at this time. |
if (lister_) |
lister_->Cancel(); |